@@ -472,25 +472,18 @@ class Config(IModule):
     def _uucmd(self):
         # create uucmd function, separate from other cmd due to nature of Config
         uucmd = self.config["uuApp"]['uuCmdList']['gatewayGetConfiguration']
+        r, err = self.g.uuapp_client.get(uucmd)
+        if r is None:
+            return False
         try:
-            r = self.g.uuapp_client.get_request(uucmd)
-            r.raise_for_status()
             new_config = r.json()
             # this is not an actual configuration key, only a remnant of server communication
-            del new_config["uuAppErrorMap"]
-        except requests.exceptions.HTTPError as e:
-            loggerc.warning("Could not fetch new data (error code %s)", r.status_code)
-            loggerc.debug("Received response: %s", r.text)
-            return False
-        except requests.exceptions.RequestException as e:
-            loggerc.info("Error in server communication: %s", e)
-            return False
+            if "uuAppErrorMap" in new_config:
+                del new_config["uuAppErrorMap"]
         except json.decoder.JSONDecodeError:
             loggerc.error("Received invalid configuration JSON from server")
             loggerc.debug("Invalid response: %s", r.text)
             return False
-        except KeyError:
-            pass
 
         if new_config == {}:
             loggerc.error("Received invalid JSON configuration from server")
