@@ -6,7 +6,8 @@ def init(config, uuclient):
 
     def cmd_heartbeat(dto_in):
         uucmd = config["uuApp"]['uuCmdList']['gatewayHeartbeat']
-        return uuclient.post_request(uucmd, dto_in)
+        resp, err = uuclient.post(uucmd, dto_in)
+        return resp
 
     gateway_config = config["gateway"]
 
